# boardgame-research  [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)

This is a list of boardgame related research papers, code, blog posts, and other media. The list primarily includes research on "solving/playing/learning" games (by various different approaches), or
occasionaly about designing or meta-aspects of the game. This doesn't cover all aspects of each game (notably missing social-science stuff), but
should be of interest to anyone interested in boardgames and their optimal play. While there is a ton of easily accessible research on games like
Chess and Go, finding prior work on more contemporary games can be a bit hard. This list focuses on the latter. If you are interested in well-researched
games like Chess, Go, Hex, take a look at the [Chess programming wiki](https://www.chessprogramming.org/Games) instead. The list also covers some computer-games that fall under similar themes.

You can browse the collection at <https://www.zotero.org/captn3m0/collections/8S9AI4TI> as well.

An importable RDF version is available as well:

- [Zotero RDF](boardgame-research.rdf)

See Import instructions here: https://www.zotero.org/support/kb/importing_standardized_formats

[Watch the repository](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/setting-up-notifications/configuring-notifications#configuring-your-watch-settings-for-an-individual-repository) to get the latest updates for now (Choose "All Activity").

If you aren't able to access any paper on this list, please [try using Sci-Hub](https://en.wikipedia.org/wiki/Sci-Hub) or [reach out to me](https://captnemo.in/contact/).

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->

- [2048](#2048)
- [Accessibility](#accessibility)
- [Azul](#azul)
- [Blokus](#blokus)
- [Carcassonne](#carcassonne)
- [Diplomacy](#diplomacy)
- [Dixit](#dixit)
- [Dominion](#dominion)
- [Frameworks](#frameworks)
- [Game Design](#game-design)
- [General Gameplay](#general-gameplay)
- [Hanabi](#hanabi)
- [Hearthstone](#hearthstone)
- [Hive](#hive)
- [Jenga](#jenga)
- [Kingdomino](#kingdomino)
- [Lost Cities](#lost-cities)
- [Mafia](#mafia)
- [Magic: The Gathering](#magic-the-gathering)
- [Mobile Games](#mobile-games)
- [Modern Art: The card game](#modern-art-the-card-game)
- [Monopoly](#monopoly)
- [Monopoly Deal](#monopoly-deal)
- [Netrunner](#netrunner)
- [Nmbr9](#nmbr9)
- [Pandemic](#pandemic)
- [Patchwork](#patchwork)
- [Pentago](#pentago)
- [Puerto Rico](#puerto-rico)
- [Quixo](#quixo)
- [Race for the Galaxy](#race-for-the-galaxy)
- [Resistance: Avalon](#resistance-avalon)
- [RISK](#risk)
- [Santorini](#santorini)
- [Scotland Yard](#scotland-yard)
- [Secret Hitler](#secret-hitler)
- [Set](#set)
- [Settlers of Catan](#settlers-of-catan)
- [Shobu](#shobu)
- [Terra Mystica](#terra-mystica)
- [Terraforming Mars](#terraforming-mars)
- [Tetris Link](#tetris-link)
- [Ticket to Ride](#ticket-to-ride)
- [Ultimate Tic-Tac-Toe](#ultimate-tic-tac-toe)
- [UNO](#uno)
- [Yahtzee](#yahtzee)
- [Similar Projects](#similar-projects)
- [License](#license)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->


# 2048
- [Systematic Selection of N-Tuple Networks for 2048](https://doi.org/10.1007%2F978-3-319-50935-8_8) (bookSection)
- [Systematic selection of N-tuple networks with consideration of interinfluence for game 2048](https://doi.org/10.1109%2Ftaai.2016.7880154) (conferencePaper)
- [An investigation into 2048 AI strategies](https://doi.org/10.1109%2Fcig.2014.6932920) (conferencePaper)
- [Threes!, Fives, 1024!, and 2048 are Hard](http://arxiv.org/abs/1505.04274v1) (journalArticle)
- [Making Change in 2048](http://arxiv.org/abs/1804.07396v1) (journalArticle)
- [Analysis of the Game "2048" and its Generalization in Higher Dimensions](http://arxiv.org/abs/1804.07393v2) (journalArticle)
- [Multi-Stage Temporal Difference Learning for 2048-like Games](http://arxiv.org/abs/1606.07374v2) (journalArticle)
- [2048 is (PSPACE) Hard, but Sometimes Easy](http://arxiv.org/abs/1408.6315v1) (journalArticle)
- [Temporal difference learning of N-tuple networks for the game 2048](http://ieeexplore.ieee.org/document/6932907/) (conferencePaper)
- [On the Complexity of Slide-and-Merge Games](http://arxiv.org/abs/1501.03837) (journalArticle)
- [2048 Without New Tiles Is Still Hard](http://drops.dagstuhl.de/opus/volltexte/2016/5885/) (journalArticle)

# Accessibility
- [Meeple Centred Design: A Heuristic Toolkit for Evaluating the Accessibility of Tabletop Games](http://link.springer.com/10.1007/s40869-018-0057-8) (journalArticle)
- [Eighteen Months of Meeple Like Us: An Exploration into the State of Board Game Accessibility](http://link.springer.com/10.1007/s40869-018-0056-9) (journalArticle)

# Azul
- [A summary of a dissertation on Azul](https://old.reddit.com/r/boardgames/comments/hxodaf/update_i_wrote_my_dissertation_on_azul/) (report)
- [Ceramic: A research environment based on the multi-player strategic board game Azul](https://ipsj.ixsq.nii.ac.jp/ej/?action=repository_action_common_download&item_id=207669&item_no=1&attribute_id=1&file_no=1) (conferencePaper)
- [Ceramic: A research environment based on the multi-player strategic board game Azul](https://github.com/Swynfel/ceramic) (computerProgram)

# Blokus
- [FPGA Blokus Duo Solver using a massively parallel architecture](http://ieeexplore.ieee.org/document/6718426/) (conferencePaper)
- [Blokus Duo game on FPGA](http://ieeexplore.ieee.org/document/6714256/) (conferencePaper)
- [Algorithm Modeling for Hardware Implementation of a Blokus Duo Player](http://artemis.library.tuc.gr/DT2014-0060/DT2014-0060.pdf) (thesis)
- [Artificial Intelligence for Blokus Classic using Heuristics, FloodFill, and Greedy Algorithm](https://ejournal-medan.uph.edu/index.php/ISD/article/view/433) (journalArticle)
- [FPGA implementation of Blokus Duo player using hardware/software co-design](http://ieeexplore.ieee.org/document/7082825/) (conferencePaper)
- [Exploring Combinatorics and Graph Theory with Simple Blokus](https://www.tandfonline.com/doi/full/10.1080/07468342.2022.2100147) (journalArticle)
- [An FPGA-based specific processor for Blokus Duo](http://ieeexplore.ieee.org/document/6718428/) (conferencePaper)
- [Blokus Game Solver](https://digitalcommons.calpoly.edu/cpesp/290/) (report)
- [Highly scalable, shared-memory, Monte-Carlo tree search based Blokus Duo Solver on FPGA](http://ieeexplore.ieee.org/document/7082823/) (conferencePaper)
- [Implementation of a highly scalable blokus duo solver on FPGA](http://ieeexplore.ieee.org/document/6718423/) (conferencePaper)
- [An implementation of Blokus Duo player on FPGA](http://ieeexplore.ieee.org/document/6718429/) (conferencePaper)
- [The Liquid Metal Blokus Duo Design](http://ieeexplore.ieee.org/document/6718425/) (conferencePaper)
- [Artificial intelligence of Blokus Duo on FPGA using Cyber Work Bench](http://ieeexplore.ieee.org/document/6718427/) (conferencePaper)
- [Hardware/software co-design architecture for Blokus Duo solver](http://ieeexplore.ieee.org/document/7082820/) (conferencePaper)
- [From C to Blokus Duo with LegUp high-level synthesis](http://ieeexplore.ieee.org/document/6718424/) (conferencePaper)
- [Blokus Duo engine on a Zynq](http://ieeexplore.ieee.org/document/7082824/) (conferencePaper)
- [Optimize MinMax algorithm to solve Blokus Duo game by HDL](http://ieeexplore.ieee.org/document/7082821/) (conferencePaper)
- [A Case Study of FPGA Blokus Duo Solver by System-Level Design](https://dl.acm.org/doi/10.1145/2693714.2693725) (journalArticle)

# Carcassonne
- [Playing Carcassonne with Monte Carlo Tree Search](http://arxiv.org/abs/2009.12974) (journalArticle)
- [On the Evolution of the MCTS Upper Confidence Bounds for Trees by Means of Evolutionary Algorithms in the Game of Carcassonne](http://arxiv.org/abs/2112.09697) (journalArticle)
- [Evolving the MCTS Upper Confidence Bounds for Trees Using a Semantic-inspired Evolutionary Algorithm in the Game of Carcassonne](http://arxiv.org/abs/2208.13589) (preprint)

# Diplomacy
- [Learning to Play No-Press Diplomacy with Best Response Policy Iteration](http://arxiv.org/abs/2006.04635v2) (journalArticle)
- [No Press Diplomacy: Modeling Multi-Agent Gameplay](http://arxiv.org/abs/1909.02128v2) (journalArticle)
- [Agent Madoff: A Heuristic-Based Negotiation Agent For The Diplomacy Strategy Game](http://arxiv.org/abs/1902.06996v1) (journalArticle)
- [Monte Carlo Tree Search for the Game of Diplomacy](https://dl.acm.org/doi/10.1145/3411408.3411413) (conferencePaper)
- [Human-Level Performance in No-Press Diplomacy via Equilibrium Search](http://arxiv.org/abs/2010.02923) (journalArticle)

# Dixit
- [Creative Captioning: An AI Grand Challenge Based on the Dixit Board Game](http://arxiv.org/abs/2010.00048) (journalArticle)
- [Dixit: Interactive Visual Storytelling via Term Manipulation](http://arxiv.org/abs/1903.02230) (journalArticle)

# Dominion
- [Dominion Simulator](https://dominionsimulator.wordpress.com/f-a-q/) (computerProgram)
- [Dominion Simulator Source Code](https://github.com/mikemccllstr/dominionstats/) (computerProgram)
- [Best and worst openings in Dominion](http://councilroom.com/openings) (blogPost)
- [Optimal Card Ratios in Dominion](http://councilroom.com/optimal_card_ratios) (blogPost)
- [Card Winning Stats on Dominion Server](http://councilroom.com/supply_win) (blogPost)
- [Dominion Strategy Forum](http://forum.dominionstrategy.com/index.php) (forumPost)
- [Clustering Player Strategies from Variable-Length Game Logs in Dominion](http://arxiv.org/abs/1811.11273) (journalArticle)
- [Game Balancing in Dominion: An Approach to Identifying Problematic Game Elements](http://cs.gettysburg.edu/~tneller/games/aiagd/papers/EAAI-00039-FordC.pdf) (journalArticle)

# Frameworks
- [RLCard: A Toolkit for Reinforcement Learning in Card Games](http://arxiv.org/abs/1910.04376) (journalArticle)
- [Design and Implementation of TAG: A Tabletop Games Framework](http://arxiv.org/abs/2009.12065) (journalArticle)
- [Game Tree Search Algorithms - C++ library for AI bot programming.](https://github.com/AdamStelmaszczyk/gtsa) (computerProgram)
- [TAG: Tabletop Games Framework](https://github.com/GAIGResearch/TabletopGames) (computerProgram)

# Game Design
- [MDA: A Formal Approach to Game Design and Game Research](https://aaai.org/Library/Workshops/2004/ws04-04-001.php) (conferencePaper)
- [Exploring anonymity in cooperative board games](http://www.digra.org/digital-library/publications/exploring-anonymity-in-cooperative-board-games/) (conferencePaper)

# General Gameplay
- [Player of Games](http://arxiv.org/abs/2112.03178) (journalArticle)
- [A general reinforcement learning algorithm that masters chess, shogi, and Go through self-play](https://www.science.org/doi/10.1126/science.aar6404) (journalArticle)

# Hanabi
- [How to Make the Perfect Fireworks Display: Two Strategies forHanabi](https://doi.org/10.4169%2Fmath.mag.88.5.323) (journalArticle)
- [Evaluating and modelling Hanabi-playing agents](https://doi.org/10.1109%2Fcec.2017.7969465) (conferencePaper)
- [The Hanabi challenge: A new frontier for AI research](https://doi.org/10.1016%2Fj.artint.2019.103216) (journalArticle)
- [The 2018 Hanabi competition](https://doi.org/10.1109%2Fcig.2019.8848008) (conferencePaper)
- [Diverse Agents for Ad-Hoc Cooperation in Hanabi](https://doi.org/10.1109%2Fcig.2019.8847944) (conferencePaper)
- [Improving Policies via Search in Cooperative Partially Observable Games](http://arxiv.org/abs/1912.02318v1) (journalArticle)
- [Hanabi is NP-hard, Even for Cheaters who Look at Their Cards](http://arxiv.org/abs/1603.01911v3) (journalArticle)
- [Generating and Adapting to Diverse Ad-Hoc Cooperation Agents in Hanabi](http://arxiv.org/abs/2004.13710v2) (journalArticle)
- [Evaluating the Rainbow DQN Agent in Hanabi with Unseen Partners](http://arxiv.org/abs/2004.13291v1) (journalArticle)
- [Re-determinizing MCTS in Hanabi]() (conferencePaper)
- [Evolving Agents for the Hanabi 2018 CIG Competition](https://ieeexplore.ieee.org/document/8490449/) (conferencePaper)
- [Aspects of the Cooperative Card Game Hanabi](http://link.springer.com/10.1007/978-3-319-67468-1_7) (bookSection)
- [Playing Hanabi Near-Optimally](http://link.springer.com/10.1007/978-3-319-71649-7_5) (bookSection)
- [An intentional AI for hanabi](http://ieeexplore.ieee.org/document/8080417/) (conferencePaper)
- [Solving Hanabi: Estimating Hands by Opponent's Actions in Cooperative Game with Incomplete Information](https://aaai.org/ocs/index.php/WS/AAAIW15/paper/view/10167) (conferencePaper)
- [A Browser-based Interface for the Exploration and Evaluation of Hanabi AIs](http://fdg2017.org/papers/FDG2017_demo_Hanabi.pdf) (journalArticle)
- [I see what you see: Integrating eye tracking into Hanabi playing agents]() (journalArticle)
- [State of the art Hanabi bots + simulation framework in rust](https://github.com/WuTheFWasThat/hanabi.rs) (computerProgram)
- [A strategy simulator for the well-known cooperative card game Hanabi](https://github.com/rjtobin/HanSim) (computerProgram)
- [A framework for writing bots that play Hanabi](https://github.com/Quuxplusone/Hanabi) (computerProgram)
- [Operationalizing Intentionality to Play Hanabi with Human Players](https://ieeexplore.ieee.org/document/9140404/) (journalArticle)
- [Behavioral Evaluation of Hanabi Rainbow DQN Agents and Rule-Based Agents](https://ojs.aaai.org/index.php/AIIDE/article/view/7404) (journalArticle)
- [Playing mini-Hanabi card game with Q-learning](http://id.nii.ac.jp/1001/00205046/) (conferencePaper)
- [Hanabi Open Agent Dataset](https://github.com/aronsar/hoad) (computerProgram)
- [Hanabi Open Agent Dataset](https://dl.acm.org/doi/10.5555/3463952.3464188) (conferencePaper)
- [Evaluation of Human-AI Teams for Learned and Rule-Based Agents in Hanabi](https://arxiv.org/abs/2107.07630) (journalArticle)
- [Emergence of Cooperative Impression With Self-Estimation, Thinking Time, and Concordance of Risk Sensitivity in Playing Hanabi](https://www.frontiersin.org/articles/10.3389/frobt.2021.658348/full) (journalArticle)
- [K-level Reasoning for Zero-Shot Coordination in Hanabi](https://papers.neurips.cc/paper/2021/hash/4547dff5fd7604f18c8ee32cf3da41d7-Abstract.html) (conferencePaper)
- [Is Vanilla Policy Gradient Overlooked? Analyzing Deep Reinforcement Learning for Hanabi](http://arxiv.org/abs/2203.11656) (journalArticle)
- [Generating and Adapting to Diverse Ad-Hoc Partners in Hanabi](https://ieeexplore.ieee.org/document/9762901/) (journalArticle)
- [Theory of Mind for Multi-agent Coordination in Hanabi](http://fse.studenttheses.ub.rug.nl/id/eprint/28327) (thesis)
- [The Hanabi challenge: From Artificial Teams to Mixed Human-Machine Teams](http://oru.diva-portal.org/smash/record.jsf?pid=diva2%3A1691114&dswid=-1981) (thesis)
- [A Graphical User Interface For The Hanabi Challenge Benchmark](http://urn.kb.se/resolve?urn=urn:nbn:se:oru:diva-94615) (thesis)
- [Analysis of Symmetry and Conventions in Off-Belief Learning (OBL) in Hanabi](https://fanpu.io/blog/2022/symmetry-and-conventions-in-obl-hanabi/) (blogPost)
- [Using intuitive behavior models to adapt to and work with human teammates in Hanabi](http://reports-archive.adm.cs.cmu.edu/anon/anon/usr0/ftp/usr/ftp/2022/abstracts/22-119.html) (thesis)
- [Behavioral Differences is the Key of Ad-hoc Team Cooperation in Multiplayer Games Hanabi](http://arxiv.org/abs/2303.06775) (preprint)
- [The Hidden Rules of Hanabi: How Humans Outperform AI Agents](https://dl.acm.org/doi/10.1145/3544548.3581550) (conferencePaper)

# Hearthstone
- [Mapping Hearthstone Deck Spaces through MAP-Elites with Sliding Boundaries](http://arxiv.org/abs/1904.10656) (journalArticle)
- [Multiplayer Tension In the Wild: A Hearthstone Case](https://research.tilburguniversity.edu/en/publications/multiplayer-tension-in-the-wild-a-hearthstone-case) (conferencePaper)
- [Improving Hearthstone AI by Combining MCTS and Supervised Learning Algorithms](http://arxiv.org/abs/1808.04794) (preprint)
- [Analysis of gameplay strategies in hearthstone: a data science approach](http://archives.njit.edu/vol01/etd/2020s/2020/njit-etd2020-006/njit-etd2020-006.pdf) (thesis)
- [Decision-Making in Hearthstone Based on Evolutionary Algorithm](https://www.cs.tsukuba.ac.jp/~hasebe/downloads/icaart2023_sakurai.pdf) (journalArticle)
- [I am a legend: Hacking hearthstone using statistical learning methods](http://ieeexplore.ieee.org/document/7860416/) (conferencePaper)
- [The Many AI Challenges of Hearthstone](http://link.springer.com/10.1007/s13218-019-00615-z) (journalArticle)
- [Evolutionary deckbuilding in hearthstone](http://ieeexplore.ieee.org/document/7860426/) (conferencePaper)
- [Evolving the Hearthstone Meta](http://arxiv.org/abs/1907.01623) (preprint)
- [Optimizing Hearthstone agents using an evolutionary algorithm](https://linkinghub.elsevier.com/retrieve/pii/S0950705119304356) (journalArticle)
- [Exploring the hearthstone deck space](https://dl.acm.org/doi/10.1145/3235765.3235791) (conferencePaper)
- [Computational Intelligence Techniques for Games with Incomplete Information](https://webthesis.biblio.polito.it/26844/) (thesis)
- [Perfect Information Hearthstone is PSPACE-hard](http://arxiv.org/abs/2305.12731) (preprint)
- [Summarizing Strategy Card Game AI Competition](http://arxiv.org/abs/2305.11814) (preprint)
- [Towards sample efficient deep reinforcement learning in collectible card games](https://linkinghub.elsevier.com/retrieve/pii/S1875952123000496) (journalArticle)

# Hive
- [On the complexity of Hive](https://dspace.library.uu.nl/handle/1874/396955) (thesis)
- [The Cost of Reinforcement Learning for Game Engines: The AZ-Hive Case-study](https://dl.acm.org/doi/10.1145/3489525.3511685) (conferencePaper)

# Jenga
- [Jidoukan Jenga: Teaching English through remixing games and game rules](https://www.llpjournal.org/2020/04/13/jidokan-jenga.html) (journalArticle)
- [Maximum genus of the Jenga like configurations](http://arxiv.org/abs/1708.01503) (journalArticle)
- [Deep Instance Segmentation and Visual Servoing to Play Jenga with a Cost-Effective Robotic System](https://www.mdpi.com/1424-8220/23/2/752) (journalArticle)

# Kingdomino
- [Monte Carlo Methods for the Game Kingdomino](https://doi.org/10.1109%2Fcig.2018.8490419) (conferencePaper)
- [Monte Carlo Methods for the Game Kingdomino](http://arxiv.org/abs/1807.04458v2) (journalArticle)
- [NP-completeness of the game Kingdomino](http://arxiv.org/abs/1909.02849v3) (journalArticle)

# Lost Cities
- [Applying Neural Networks and Genetic Programming to the Game Lost Cities](https://minds.wisconsin.edu/bitstream/handle/1793/79080/LydeenSpr18.pdf?sequence=1&isAllowed=y) (conferencePaper)

# Mafia
- [A mathematical model of the Mafia game](http://arxiv.org/abs/1009.1031v3) (journalArticle)
- [Automatic Long-Term Deception Detection in Group Interaction Videos](http://arxiv.org/abs/1905.08617) (journalArticle)
- [Human-Side Strategies in the Werewolf Game Against the Stealth Werewolf Strategy](http://link.springer.com/10.1007/978-3-319-50935-8_9) (bookSection)
- [A Theoretical Study of Mafia Games](http://arxiv.org/abs/0804.0071) (journalArticle)

# Magic: The Gathering
- [Ensemble Determinization in Monte Carlo Tree Search for the Imperfect Information Card Game Magic: The Gathering](https://doi.org/10.1109%2Ftciaig.2012.2204883) (journalArticle)
- [Optimal Card-Collecting Strategies for Magic: The Gathering](https://doi.org/10.1080%2F07468342.2000.11974103) (journalArticle)
- [Monte Carlo search applied to card selection in Magic: The Gathering](https://doi.org/10.1109%2Fcig.2009.5286501) (conferencePaper)
- [Magic: the Gathering is as Hard as Arithmetic](http://arxiv.org/abs/2003.05119v1) (journalArticle)
- [Magic: The Gathering is Turing Complete](http://arxiv.org/abs/1904.09828v2) (journalArticle)
- [Neural Networks Models for Analyzing Magic: the Gathering Cards](http://arxiv.org/abs/1810.03744v1) (journalArticle)
- [Neural Networks Models for Analyzing Magic: The Gathering Cards](http://link.springer.com/10.1007/978-3-030-04179-3_20) (bookSection)
- [The Complexity of Deciding Legality of a Single Step of Magic: The Gathering](https://livrepository.liverpool.ac.uk/3029568/) (conferencePaper)
- [Magic: The Gathering in Common Lisp](https://vixra.org/abs/2001.0065) (conferencePaper)
- [Magic: The Gathering in Common Lisp](https://github.com/jeffythedragonslayer/maglisp) (computerProgram)
- [Mathematical programming and Magic: The Gathering](https://commons.lib.niu.edu/handle/10843/19194) (thesis)
- [Deck Construction Strategies for Magic: The Gathering](https://www.doi.org/10.1685/CSC06077) (conferencePaper)
- [Deckbuilding in Magic: The Gathering Using a Genetic Algorithm](https://doi.org/11250/2462429) (thesis)
- [Magic: The Gathering Deck Performance Prediction](http://cs229.stanford.edu/proj2012/HauPlotkinTran-MagicTheGatheringDeckPerformancePrediction.pdf) (report)
- [AI solutions for drafting in Magic: the Gathering](http://arxiv.org/abs/2009.00655) (journalArticle)

# Mobile Games
- [Trainyard is NP-Hard](http://arxiv.org/abs/1603.00928v1) (journalArticle)
- [Threes!, Fives, 1024!, and 2048 are Hard](http://arxiv.org/abs/1505.04274v1) (journalArticle)
- [Rikudo is NP-complete](https://linkinghub.elsevier.com/retrieve/pii/S0304397522000457) (journalArticle)

# Modern Art: The card game
- [A constraint programming based solver for Modern Art](https://github.com/captn3m0/modernart) (computerProgram)

# Monopoly
- [Monopoly as a Markov Process](https://doi.org/10.1080%2F0025570x.1972.11976187) (journalArticle)
- [Learning Monopoly Gameplay: A Hybrid Model-Free Deep Reinforcement Learning and Imitation Learning Approach](http://arxiv.org/abs/2103.00683) (journalArticle)
- [Negotiation strategy of agents in the MONOPOLY game](http://ieeexplore.ieee.org/document/1013210/) (conferencePaper)
- [Generating interesting Monopoly boards from open data](http://ieeexplore.ieee.org/document/6374168/) (conferencePaper)
- [Estimating the probability that the game of Monopoly never ends](http://ieeexplore.ieee.org/document/5429349/) (conferencePaper)
- [Learning to Play Monopoly with Monte Carlo Tree Search](https://project-archive.inf.ed.ac.uk/ug4/20181042/ug4_proj.pdf) (report)
- [Monopoly Using Reinforcement Learning](https://ieeexplore.ieee.org/document/8929523/) (conferencePaper)
- [A Markovian Exploration of Monopoly](https://pi4.math.illinois.edu/wp-content/uploads/2014/10/Gartland-Burson-Ferguson-Markovopoly.pdf) (report)
- [Learning to play Monopoly: A Reinforcement Learning approach](https://intelligence.csd.auth.gr/publication/conference-papers/learning-to-play-monopoly-a-reinforcement-learning-approach/) (conferencePaper)
- [What’s the Best Monopoly Strategy?](https://core.ac.uk/download/pdf/48614184.pdf) (presentation)

# Monopoly Deal
- [Implementation of Artificial Intelligence with 3 Different Characters of AI Player on “Monopoly Deal” Computer Game](https://doi.org/10.1007%2F978-3-662-46742-8_11) (bookSection)

# Netrunner
- [Netrunner Mate-in-1 or -2 is Weakly NP-Hard](http://arxiv.org/abs/1710.05121) (journalArticle)

# Nmbr9
- [Nmbr9 as a Constraint Programming Challenge](http://arxiv.org/abs/2001.04238) (journalArticle)
- [Nmbr9 as a Constraint Programming Challenge](https://zayenz.se/blog/post/nmbr9-cp2019-abstract/) (blogPost)

# Pandemic
- [NP-Completeness of Pandemic](https://www.jstage.jst.go.jp/article/ipsjjip/20/3/20_723/_article) (journalArticle)

# Patchwork
- [State Representation and Polyomino Placement for the Game Patchwork](https://zayenz.se/blog/post/patchwork-modref2019-paper/) (blogPost)
- [State Representation and Polyomino Placement for the Game Patchwork](http://arxiv.org/abs/2001.04233) (journalArticle)
- [State Representation and Polyomino Placement for the Game Patchwork](https://zayenz.se/papers/Lagerkvist_ModRef_2019_Presentation.pdf) (presentation)

# Pentago
- [On Solving Pentago](http://www.ke.tu-darmstadt.de/lehre/arbeiten/bachelor/2011/Buescher_Niklas.pdf) (thesis)
- [Pentago is a First Player Win: Strongly Solving a Game Using Parallel In-Core Retrograde Analysis](http://arxiv.org/abs/1404.0743) (journalArticle)
- [A massively parallel pentago solver](https://github.com/girving/pentago) (computerProgram)
- [An interactive explorer for perfect pentago play](https://perfect-pentago.net/) (computerProgram)
- [An Application of Machine Learning to the Board Game Pentago](http://cs229.stanford.edu/proj2012/HeonOetting-AnAppliactionOfMachineLearningToTheBoardGamePentago.pdf) (report)
- [Learning finite functions by neural networks : Evaluation of Pentago positions by convolutional neural networks](https://repository.kulib.kyoto-u.ac.jp/dspace/handle/2433/251730) (report)

# Puerto Rico
- [Artificial Intelligence Techniques for the Puerto Rico Strategy Game](http://link.springer.com/10.1007/978-3-319-59394-4_8) (bookSection)

# Quixo
- [QUIXO is EXPTIME-complete](https://doi.org/10.1016%2Fj.ipl.2020.105995) (journalArticle)
- [Quixo Is Solved](http://arxiv.org/abs/2007.15895) (journalArticle)

# Race for the Galaxy
- [SCOUT: A Case-Based Reasoning Agent for Playing Race for the Galaxy](https://doi.org/10.1007%2F978-3-319-61030-6_27) (bookSection)
- [Ludometrics: Luck, and How to Measure It](http://arxiv.org/abs/1811.00673) (journalArticle)

# Resistance: Avalon
- [Finding Friend and Foe in Multi-Agent Games](http://arxiv.org/abs/1906.02330) (journalArticle)

# RISK
- [Mini-Risk: Strategies for a Simplified Board Game](https://doi.org/10.1057%2Fjors.1990.2) (journalArticle)
- [Learning the risk board game with classifier systems](https://doi.org/10.1145%2F508791.508904) (conferencePaper)
- [Markov Chains and the RISK Board Game](https://doi.org/10.1080%2F0025570x.1997.11996573) (journalArticle)
- [Markov Chains for the RISK Board Game Revisited](https://doi.org/10.1080%2F0025570x.2003.11953165) (journalArticle)
- [Planning an Endgame Move Set for the Game RISK: A Comparison of Search Algorithms](https://doi.org/10.1109%2Ftevc.2005.856211) (journalArticle)
- [An Intelligent Artificial Player for the Game of Risk](http://www.ke.tu-darmstadt.de/lehre/archiv/ss04/oberseminar/folien/Wolf_Michael-Slides.pdf) (presentation)
- [RISKy Business: An In-Depth Look at the Game RISK](https://scholar.rose-hulman.edu/rhumj/vol3/iss2/3) (journalArticle)
- [RISK Board Game ‐ Battle Outcome Analysis](http://www.c4i.gr/xgeorgio/docs/RISK-board-game%20_rev-3.pdf) (journalArticle)
- [A multi-agent system for playing the board game risk](http://urn.kb.se/resolve?urn=urn:nbn:se:bth-3781) (thesis)
- [Monte Carlo Tree Search for Risk](https://www.sto.nato.int/publications/STO%20Meeting%20Proceedings/STO-MP-SAS-OCS-ORA-2020/MP-SAS-OCS-ORA-2020-WCM-01.pdf) (conferencePaper)
- [Wargaming with Monte-Carlo Tree Search](https://www.sto.nato.int/publications/STO%20Meeting%20Proceedings/STO-MP-SAS-OCS-ORA-2020/MP-SAS-OCS-ORA-2020-WCM-01P.pdf) (presentation)

# Santorini
- [A Mathematical Analysis of the Game of Santorini](https://openworks.wooster.edu/independentstudy/8917/) (thesis)
- [A Mathematical Analysis of the Game of Santorini](https://github.com/carsongeissler/SantoriniIS) (computerProgram)

# Scotland Yard
- [The complexity of Scotland Yard](https://eprints.illc.uva.nl/id/eprint/193/1/PP-2006-18.text.pdf) (report)

# Secret Hitler
- [Competing in a Complex Hidden Role Game with Information Set Monte Carlo Tree Search](http://arxiv.org/abs/2005.07156) (journalArticle)

# Set
- [Game, Set, Math](https://doi.org/10.4169%2Fmath.mag.85.2.083) (journalArticle)
- [The Joy of SET](https://doi.org/10.1080%2F00029890.2018.1412661) (journalArticle)

# Settlers of Catan
- [The effectiveness of persuasion in The Settlers of Catan](https://doi.org/10.1109%2Fcig.2014.6932861) (conferencePaper)
- [Avoiding Revenge Using Optimal Opponent Ranking Strategy in the Board Game Catan](https://doi.org/10.4018%2Fijgcms.2018040103) (journalArticle)
- [Game strategies for The Settlers of Catan](https://doi.org/10.1109%2Fcig.2014.6932884) (conferencePaper)
- [Monte-Carlo Tree Search in Settlers of Catan](https://doi.org/10.1007%2F978-3-642-12993-3_3) (bookSection)
- [Deep Reinforcement Learning in Strategic Board Game Environments](https://doi.org/10.1007%2F978-3-030-14174-5_16) (bookSection)
- [Settlers of Catan bot trained using reinforcement learning](https://jonzia.github.io/Catan/) (computerProgram)
- [Trading in a multiplayer board game: Towards an analysis of non-cooperative dialogue](https://escholarship.org/uc/item/9zt506xx) (conferencePaper)
- [POMCP with Human Preferencesin Settlers of Catan](https://www.aaai.org/ocs/index.php/AIIDE/AIIDE18/paper/viewFile/18091/17217) (journalArticle)
- [The impact of loaded dice in Catan](https://izbicki.me/blog/how-to-cheat-at-settlers-of-catan-by-loading-the-dice-and-prove-it-with-p-values.html) (blogPost)
- [Monte Carlo Tree Search in a Modern Board Game Framework](https://project.dke.maastrichtuniversity.nl/games/files/bsc/Roelofs_Bsc-paper.pdf) (journalArticle)
- [Reinforcement Learning of Strategies for Settlers of Catan](https://www.researchgate.net/publication/228728063_Reinforcement_learning_of_strategies_for_Settlers_of_Catan) (conferencePaper)
- [Playing Catan with Cross-dimensional Neural Network](http://arxiv.org/abs/2008.07079) (journalArticle)
- [Strategic Dialogue Management via Deep Reinforcement Learning](http://arxiv.org/abs/1511.08099) (journalArticle)
- [Analysis of 'The Settlers of Catan' Using Markov Chains](https://repository.tcu.edu/handle/116099117/49062) (thesis)
- [Learning to Play Settlers of Catan with Deep Reinforcement Learning](https://settlers-rl.github.io/) (blogPost)
- [Using Ant Colony Optimisation for map generation and improving game balance in the Terra Mystica and Settlers of Catan board games](https://dl.acm.org/doi/10.1145/3402942.3409778) (conferencePaper)

# Shobu
- [Shobu AI Playground](https://github.com/JayWalker512/Shobu) (computerProgram)
- [Shobu randomly played games dataset](https://www.kaggle.com/bsfoltz/shobu-randomly-played-games-104k) (webpage)

# Terra Mystica
- [Using Tabu Search Algorithm for Map Generation in the Terra Mystica Tabletop Game](https://doi.org/10.1145%2F3396474.3396492) (conferencePaper)
- [Mastering Terra Mystica: Applying Self-Play to Multi-agent Cooperative Board Games](http://arxiv.org/abs/2102.10540) (journalArticle)
- [TM AI: Play TM against AI players.](https://lodev.org/tmai/) (computerProgram)
- [Using Ant Colony Optimisation for map generation and improving game balance in the Terra Mystica and Settlers of Catan board games](https://dl.acm.org/doi/10.1145/3402942.3409778) (conferencePaper)
- [Map Generation and Balance in the Terra Mystica Board Game Using Particle Swarm and Local Search](http://link.springer.com/10.1007/978-3-030-53956-6_15) (bookSection)
- [Using Ant Colony Optimisation for map generation and improving game balance in the Terra Mystica and Settlers of Catan board games](https://dl.acm.org/doi/10.1145/3402942.3409778) (conferencePaper)

# Terraforming Mars
- [TAG: Terraforming Mars](https://ojs.aaai.org/index.php/AIIDE/article/view/18902) (journalArticle)

# Tetris Link
- [A New Challenge: Approaching Tetris Link with AI](http://arxiv.org/abs/2004.00377) (journalArticle)

# Ticket to Ride
- [AI-based playtesting of contemporary board games](http://dl.acm.org/citation.cfm?doid=3102071.3102105) (conferencePaper)
- [Materials for Ticket to Ride Seattle and a framework for making more game boards](https://github.com/dovinmu/ttr_generator) (computerProgram)
- [The Difficulty of Learning Ticket to Ride](https://www.eecs.tufts.edu/~jsinapov/teaching/comp150_RL/reports/Nguyen_Dinjian_report.pdf) (report)
- [Evolving maps and decks for ticket to ride](https://dl.acm.org/doi/10.1145/3235765.3235813) (conferencePaper)
- [Applications of Graph Theory and Probability in the Board Game Ticket to Ride](https://www.rtealwitter.com/slides/2020-JMM.pdf) (presentation)

# Ultimate Tic-Tac-Toe
- [At Most 43 Moves, At Least 29: Optimal Strategies and Bounds for Ultimate Tic-Tac-Toe](http://arxiv.org/abs/2006.02353) (journalArticle)

# UNO
- [UNO Is Hard, Even for a Single Player](https://doi.org/10.1007%2F978-3-642-13122-6_15) (bookSection)
- [The complexity of UNO](http://arxiv.org/abs/1003.2851v3) (journalArticle)

# Yahtzee
- [Nearly Optimal Computer Play in Multi-player Yahtzee](https://doi.org/10.1007%2F978-3-642-17928-0_23) (bookSection)
- [Computer Strategies for Solitaire Yahtzee](https://doi.org/10.1109%2Fcig.2007.368089) (conferencePaper)
- [Modeling expert problem solving in a game of chance: a Yahtzeec case study](https://doi.org/10.1111%2F1468-0394.00160) (journalArticle)
- [Probabilites In Yahtzee](https://pubs.nctm.org/view/journals/mt/75/9/article-p751.xml) (journalArticle)
- [Optimal Solitaire Yahtzee Strategies](http://www.yahtzee.org.uk/optimal_yahtzee_TV.pdf) (presentation)
- [Yahtzee: a Large Stochastic Environment for RL Benchmarks](http://researchers.lille.inria.fr/~lazaric/Webpage/PublicationsByTopic_files/bonarini2005yahtzee.pdf) (journalArticle)
- [Optimal Yahtzee performance in multi-player games](https://www.csc.kth.se/utbildning/kth/kurser/DD143X/dkand13/Group4Per/report/12-serra-widell-nigata.pdf) (thesis)
- [How to Maximize Your Score in Solitaire Yahtzee](http://www-set.win.tue.nl/~wstomv/misc/yahtzee/yahtzee-report-unfinished.pdf) (manuscript)
- [Using Deep Q-Learning to Compare Strategy Ladders of Yahtzee](https://raw.githubusercontent.com/philvasseur/Yahtzee-DQN-Thesis/dcf2bfe15c3b8c0ff3256f02dd3c0aabdbcbc9bb/webpage/final_report.pdf) (thesis)
- [Defensive Yahtzee](http://urn.kb.se/resolve?urn=urn:nbn:se:kth:diva-168668) (report)
- [An Optimal Strategy for Yahtzee](http://www.cs.loyola.edu/~jglenn/research/optimal_yahtzee.pdf) (report)
- [Let’s Get Rolling! Exact Optimal Solitaire Yahtzee](https://www.tandfonline.com/doi/full/10.1080/0025570X.2022.2055334) (journalArticle)
# Similar Projects

- https://github.com/benedekrozemberczki/awesome-monte-carlo-tree-search-papers

# License

Creative Commons Zero v1.0 Universal. See LICENSE file for complete text.